#
# spec file for package libsigrok
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libsigrok
Version:        0.5.1
Release:        lp151.22.4
%define libname %{name}4
%define libcxxname libsigrokcxx4
Summary:        API for talking to logic analyzer hardware
License:        GPL-3.0-or-later
Group:          Productivity/Scientific/Electronics
Url:            http://sigrok.org
Source0:        http://sigrok.org/download/source/libsigrok/%{name}-%{version}.tar.gz
Source1:        sigrok-mime.xml
BuildRequires:  alsa-devel
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  check-devel >= 0.9.4
BuildRequires:  doxygen
BuildRequires:  gcc-c++
BuildRequires:  glib2-devel >= 2.32.0
BuildRequires:  hicolor-icon-theme
BuildRequires:  libftdi1-devel >= 1.0
BuildRequires:  libserialport-devel >= 0.1.1
BuildRequires:  libtool
BuildRequires:  libudev-devel
BuildRequires:  libusb-1_0-devel
BuildRequires:  libzip-devel >= 0.10
BuildRequires:  zlib-devel
BuildRequires:  pkgconfig(glibmm-2.4)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
libsigrok is a shared library written in C which provides the basic API
for talking to logic analyzer hardware and reading/writing the acquired data
into various input/output file formats.

%package     -n %{libname}
Summary:        API for talking to logic analyzer hardware
Group:          System/Libraries
Requires:       %{name}-data >= %{version}
Recommends:     sigrok-firmware-fx2lafw

%description -n %{libname}
libsigrok is a shared library written in C which provides the basic API
for talking to logic analyzer hardware and reading/writing the acquired data
into various input/output file formats.

%package     -n %{libcxxname}
Summary:        API for talking to logic analyzer hardware
Group:          System/Libraries
Requires:       %{libname} >= %{version}
Requires:       %{name}-data >= %{version}

%description -n %{libcxxname}
libsigrok is a shared library written in C which provides the basic API
for talking to logic analyzer hardware and reading/writing the acquired data
into various input/output file formats.

%package        data
Summary:        Data files for libsigrok
Group:          Productivity/Scientific/Electronics
BuildArch:      noarch
Requires:       hicolor-icon-theme
Requires(post):    shared-mime-info
Requires(postun):  shared-mime-info

%description    data
libsigrok is a shared library written in C which provides the basic API
for talking to logic analyzer hardware and reading/writing the acquired data
into various input/output file formats.

%package        devel
Summary:        Development files for libsigrok, an API for talking to logic analyzer hardware
Group:          Development/Libraries/C and C++
Requires:       %{libcxxname} = %{version}
Requires:       %{libname} = %{version}

%description    devel
libsigrok is a shared library written in C which provides the basic API
for talking to logic analyzer hardware and reading/writing the acquired data
into various input/output file formats.

This subpackage contains the headers to make use of the sigrok shared
libraries.

%prep
%setup -q

%build
%configure \
        --disable-static \
        --enable-fx2lafw
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install
find %{buildroot} -type f -name "*.la" -delete -print

%define mm_ignore ENV{ID_MM_DEVICE_IGNORE}="1"
install -d -m 755 %{buildroot}%{_udevrulesdir}
install -m 644 contrib/60-libsigrok.rules %{buildroot}%{_udevrulesdir}
install -m 644 contrib/61-libsigrok-uaccess.rules %{buildroot}%{_udevrulesdir}
sed -i '/ID_SIGROK/ p; s/TAG.*/%{mm_ignore}/' %{buildroot}%{_udevrulesdir}/61-libsigrok-uaccess.rules

install -m 644 -D %{SOURCE1} %{buildroot}%{_datadir}/mime/packages/vnd.sigrok.session.xml
install -m 644 -D contrib/libsigrok.png %{buildroot}%{_datadir}/icons/hicolor/48x48/mimetypes/libsigrok.png
install -m 644 -D contrib/libsigrok.svg %{buildroot}%{_datadir}/icons/hicolor/scalable/mimetypes/libsigrok.svg

%post data
%mime_database_post
%icon_theme_cache_post

%postun data
%mime_database_postun
%icon_theme_cache_postun

%post -n %{libname} -p /sbin/ldconfig

%postun -n %{libname} -p /sbin/ldconfig

%post -n %{libcxxname} -p /sbin/ldconfig

%postun -n %{libcxxname} -p /sbin/ldconfig

%files -n %{libname}
%{_libdir}/*.so.*
%exclude %{_libdir}/*cxx.so.*

%files -n %{libcxxname}
%{_libdir}/*cxx.so.*

%files data
%license COPYING
%{_udevrulesdir}/*
%{_datadir}/mime/packages/*
%{_datadir}/icons/hicolor/*/mimetypes/libsigrok*

%files devel
%doc README HACKING NEWS
%{_libdir}/*.so
%{_includedir}/*
%{_libdir}/pkgconfig/*

%changelog
* Sun Oct 14 2018 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 0.5.1
  * New supported hardware:
    + Logic analyzers: DreamSourceLab DSLogic Basic/Plus, Hantek 4032L,
    IPDBG (ipdbg.org FPGA IP debugger), Meilhaus Logian-16L,
    Saleae Logic Pro 16, ZEROPLUS Logic Cube LAP-C (16128+) / LAP-16032U
    + Oscilloscopes: Agilent MSO7034A, Hantek DSO-2250, Rigol DS4000 series,
    Siglent SDS1000/SDS2000 series
    + Programmable power supplies: GW Instek GPD series,
    HP 6631B/66332A/6633B/6634B, Korad KD3005P, RDTech DPS/DPH series,
    Rigol DP711/DP712, RND KA3005P, Tenma 72-2540
    + Electronic loads: ZKETECH EBD-USB
    + Multimeters: EEVblog 121GW, Fluke 45, HP 3478A, MASTECH MS8250D,
    Metex M-3860M, PeakTech 4390A, SparkFun 70C,
    Victor DMMs with Mini-USB connector, Voltcraft VC-96
  * Various fixes and improvements
  * The API and ABI is backwards compatible with 0.5.0
  * Move COPYING from devel to data subpackage, tag as %%license
* Sat Jul  1 2017 stefan.bruens@rwth-aachen.de
- Remove Obsoletes: libsigrok3. Obsoletes implies a conflict, so
  there is no way in rpm to trigger deinstalation of deprecated
  shared library packages.
* Sun Jun 18 2017 stefan.bruens@rwth-aachen.de
- Add Recommends: sigrok-firmware-fx2lafw
  The fx2lafw is required for many USB logic analyzers, while
  most other devices have a persistent firmware
* Wed Jun 14 2017 stefan.bruens@rwth-aachen.de
- Delete obsolete fix_unknown_types_declarations.diff (openSUSE <= 13.1)
* Tue Jun 13 2017 stefan.bruens@rwth-aachen.de
- Update to version 0.5.0
  * New supported hardware:
  - Logic analyzers:
  - CWAV USBee ZX
  - DreamSourceLab DSLogic and DSLogic Pro
  - FTDI LA (simple, limited logic analyzer using FTDI chips directly)
  - Oscilloscopes:
  - Hameg HMO3524
  - Hantek 6022BE
  - LeCroy X-Stream series
  - Rigol DS1074Z Plus
  - Rigol DS1104Z Plus
  - Rigol MSO2000A series
  - Rocktech BM102
  - Rohde&Schwarz HMO 1002
  - Sainsmart DDS120
  - Logic analyzers / oscilloscopes (but not MSOs):
  - Hantek 6022BL
  - Programmable power supplies:
  - Agilent N5763A
  - HP 6633A
  - Rohde&Schwarz HMC8043
  - Electronic loads:
  - Arachnid Labs Re:load Pro
  - Multimeters:
  - Agilent U1241C/U1242C
  - Fluke 289
  - HP 3457A
  - Keysight U1281/U1282
  - Metrix MX56C
  - PeakTech 3330
  - Sound level meters:
  - PCE PCE-322A
  - LCR meters:
  - PeakTech 2170
  - Signal generators:
  - Rohde&Schwarz SME0x series
  * IANA registered mimetype: vnd.sigrok.session
  * Bump soversions (libsigrok4, libsigrokcxx4)
* Mon Oct 24 2016 jengelh@inai.de
- Update summaries and descriptions
* Sat Oct 22 2016 stefan.bruens@rwth-aachen.de
- Add application/x-sigrok-dump mimetype and corresponding icons
  to data subpackage
* Sun Apr 17 2016 stefan.bruens@rwth-aachen.de
- Add MM_DEVICE_IGNORE udev flag for all devices supported by libsigrok
* Sat Jan 30 2016 stefan.bruens@rwth-aachen.de
- Update to version 0.4.0
  * New supported hardware:
  - Logic analyzers:
  - AKIP-9101
  - BeagleLogic
  - LeCroy LogicStudio
  - mcupro Logic16 clone
  - Pipistrello OLS
  - SysClk LWLA1016
  - Oscilloscopes
  - Rigol/Agilent DS1000Z series
  - Yokogawa DLM2000 series
  - Yokogawa DL9000 series
  - Hung-Chang DSO-2100
  - GW Instek GDS-800
  - Multimeters
  - Agilent U1241A/B
  - Agilent U1242A/B
  - Brymen BM25x series
  - MASTECH MS8250B
  - Metrahit 16T/16U/KMM2002
  - PeakTech 3415
  - Tenma 72-7730/72-7732/72-9380A
  - Testo 435-4
  - UNI-T UT372
  - UNI-T UT71A/B/C/D/E
  - Velleman DVM4100
  - Voltcraft VC-870/VC-920/VC-940/VC-960
    Programmable power supplies
  - Fluke/Philips PM2800 series
  - HP 663xx series
  - Manson HCS-3xxx series
  - Motech LPS-30x series
  - Rigol DP800 series
  - Korad KAxxxxP series (a.k.a Velleman LABPS3005D and others)
  - AC/DC sources
  - Agilent N5700A series (DC sources)
  - Chroma 61600 series (AC sources)
  - Chroma 62000 series (DC sources)
  - Electronic loads
  - Maynuo M97 (and compatibles)
  - LCR meters
  - DER EE DE-5000
  - Scales
  - KERN EW 6200-2NM
  - BeagleBone Black capes
  - BayLibre ACME (revA and revB)
* Sat Oct  3 2015 stefan.bruens@rwth-aachen.de
- fix build on openSUSE 13.1
  * Add fix_unknown_types_declarations.diff
- require libsigrok from libsigrokcxx with same version
- update source from GIT
* Fri Sep 25 2015 stefan.bruens@rwth-aachen.de
- Track GIT version (upcoming 0.4.0)
  * build C++ binding (libsigrokcxx), needed for pulseview
* Wed Aug  6 2014 dmitry_r@opensuse.org
- Move udev rules to libsigrok-data due to SLPP
* Mon Jun  2 2014 bugs@vdm-design.de
- Sync spec file with libsigrok.spec from rmax
* Fri May 30 2014 bugs@vdm-design.de
- Update to version 0.3.0
  * New supported hardware:
  - Logic analyzers:
  - ChronoVu LA16
  - Sysclk LWLA1034
  - Oscilloscopes:
  - Agilent DSO1000 series
  - Hameg HMO compact series
  - Rigol DS2000 series
  - Rigol VS5000 series
  - Multimeters:
  - BBC Goerz Metrawatt M2110
  - Brymen BM869
  - Fluke 189
  - Gossen Metrawatt MetraHIT 1x/2x series
  - Tenma 72-7745/72-7750 (rebadged UNI-T UT60E/UT60G)
  - UNI-T UT60G/UT61B/UT61C
  - V&A VA40B
  - Voltcraft M-3650CR/ME-42
  - Thermometers:
  - APPA 55II
  - Programmable power supplies:
  - Atten PPS3000 series
  - Conrad DIGI 35 CPU
  * Most important changes:
  - We added support for channel groups (multiple channels of the device, that share some properties and are configured together).
  - There's a generic SCPI backend now that drivers can use, supporting various transports: serial ports, USBTMC, TCP/RAW, TCP/Rigol, VXI, and librevisa.
  - The session file format (*.sr) has changed and its version was bumped to 2.
  - There's improved Windows support now for serial port and USB based devices, though it's partially still experimental! Please checkout the current list of known Windows issues, since there are some problems e.g. with the popular FX2 based devices (bug #343) and the Openbench Logic Sniffer (bug #205). Feedback, bug reports and patches are highly welcome!
  - Various API improvements were also done, to allow for some of the new features and to ease future extendability. You can take a look at the API docs for more details.
* Mon Dec 16 2013 bugs@vdm-design.de
- Update to version 0.2.2
  * New supported hardware:
  - Logic analyzers:
  - Saleae Logic16
  - Thermometers:
  - Center 309
  - UNI-T UT325
  - Voltcraft K204
  - Multimeters:
  - ISOTECH IDM103N
  - Metex M-4650CR
  - Norma DM950
  - Voltcraft M-4650CR
  - Energy meters:
  - EDF Teleinfo
  * New config keys:
  - SR_CONF_VOLTAGE_THRESHOLD
  - SR_CONF_EXTERNAL_CLOCK
  - SR_CONF_SWAP
  - SR_CONF_ENERGYMETER
  * New config info types:
  - SR_T_DOUBLE_RANGE
  * New units:
  - SR_UNIT_REVOLUTIONS_PER_MINUTE
  - SR_UNIT_VOLT_AMPERE
  - SR_UNIT_WATT
  - SR_UNIT_WATT_HOUR
  * New input modules:
  - csv (comma-separated values)
  * Bump required libzip version to >= 0.10.
  * uni-t-dmm: This driver now requires the specification of the USB VID/PID
  of the cable that is used. Example for sigrok-cli:
  - Old: sigrok-cli --driver voltcraft-vc820 ...
  - New: sigrok-cli --driver voltcraft-vc820:conn=1a86.e008 ...
  * openbench-logic-sniffer:
  - Initial test pattern support (SR_CONF_PATTERN_MODE).
  - Initial external clock support (SR_CONF_EXTERNAL_CLOCK).
  - Initial channel swap support (SR_CONF_SWAP).
  - Various minor fixes and improvements.
  * When a frontend adds a device instance to a running session, start
  acquisition on it. This helps with the collectd use-case where devices
  can be removed and added dynamically while a session is running.
  * rigol-ds1xx2: Support newer Linux kernels with USBTMC in /sys/class/usbmisc.
  * rigol-ds1xx2: Also detect the Rigol DS1152E/DS1152D.
  * agilent-dmm: Fix a segfault happening in certain cases.
  * output/analog: Support all currently known MQFLAGs.
  * Fix a minor compile issue due to an incorrect #include.
  * Fix two compile issues on FreeBSD (bug #185).
  * es519xx: New generic parser for various Cyrustek DMM ICs.
  * es51922/fs9721/fs9922/metex14: Use diode MQFLAG (bug #141).
  * voltcraft-vc830: Fix diode mode handling (bug #142).
  * Add the missing HACKING file to the tarball.
  * README.devices: Updates/notes for newly added devices.
* Sun Aug 11 2013 bugs@vdm-design.de
- Update to version 0.2.1
  * New supported hardware:
  - Logic analyzers:
  - IKALOGIC Scanalogic-2
  - IKALOGIC ScanaPLUS
  - Sound level meters:
  - CEM DT-8852
  - Kecheng KC-330B
  - Multimeters:
  - UNI-T UT60A
  - UNI-T UT60E
  - Voltcraft M-3650D
  - Voltcraft VC-830
  * Drop the Tecpel DMM-8060 (doesn't have PC connectivity).
  * New config keys:
  - SR_CONF_SPL_WEIGHT_FREQ
  - SR_CONF_SPL_WEIGHT_TIME
  - SR_CONF_SPL_MEASUREMENT_RANGE
  - SR_CONF_HOLD_MIN
  - SR_CONF_HOLD_MAX
  - SR_CONF_POWER_OFF
  - SR_CONF_DATA_SOURCE
  * New config info types:
  - SR_T_UINT64_RANGE
  * New error codes:
  - SR_ERR_TIMEOUT
  * Always link against libm, the math library (bug #115).
  * Fix a bug in sr_si_string_u64() at al (bug #73).
  * output/csv: Fix incorrect probe order.
  * alsa: Fix a double-free issue (bug #129).
  * zeroplus-logic-cube: Fix a bug in the driver cleanup code.
  * ikalogic-scanalogic2: Use GET_REPORT (bug #130).
  * uni-t-dmm: Fix a bug breaking the UNI-T UT61E (bug #136).
  * Various internal consistency fixes and code cleanups.
  * Improved Doxygen documentation.
  * Fixed various memory leaks.
* Wed Jan 30 2013 max@suse.com
- Install udev rules to give local users access to sigrok devices.
* Wed Jan 16 2013 max@suse.com
- Initial build from cvs.
